==> drd-8.x-3.0.tar.gz: drd/src/Entity/RequirementInterface.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\RequirementInterface.
 */

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Requirement entities.
 *
 * @ingroup drd
 */
interface RequirementInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Requirement name.
   *
   * @return string
   *   Name of the Requirement.
   */
  public function getName();

  /**
   * Sets the Requirement name.
   *
   * @param string $name
   *   The Requirement name.
   *
   * @return \Drupal\drd\Entity\RequirementInterface
   *   The called Requirement entity.
   */
  public function setName($name);

  /**
   * Gets the Requirement creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Requirement.
   */
  public function getCreatedTime();

  /**
   * Sets the Requirement creation timestamp.
   *
   * @param int $timestamp
   *   The Requirement creation timestamp.
   *
   * @return \Drupal\drd\Entity\RequirementInterface
   *   The called Requirement entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Requirement published status indicator.
   *
   * Unpublished Requirement are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Requirement is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Requirement.
   *
   * @param bool $published
   *   TRUE to set this Requirement to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\Entity\RequirementInterface
   *   The called Requirement entity.
   */
  public function setPublished($published);

  /**
   * Returns the Requirements ignored indicator.
   *
   * @return bool
   *   TRUE if the Requirement is ignored.
   */
  public function isIgnored();

  /**
   * @param string $key
   * @param string $label
   * @return Requirement
   *
   * @throws \Exception
   */
  public static function findOrCreate($key, $label);

  /**
   * @return array
   */
  public static function getCategoryKeys();

}

==> drd-8.x-3.4.tar.gz: drd/src/Entity/RequirementInterface.php <==
<?php

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Requirement entities.
 *
 * @ingroup drd
 */
interface RequirementInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Requirement name.
   *
   * @return string
   *   Name of the Requirement.
   */
  public function getName();

  /**
   * Sets the Requirement name.
   *
   * @param string $name
   *   The Requirement name.
   *
   * @return RequirementInterface
   *   The called Requirement entity.
   */
  public function setName($name);

  /**
   * Gets the Requirement creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Requirement.
   */
  public function getCreatedTime();

  /**
   * Sets the Requirement creation timestamp.
   *
   * @param int $timestamp
   *   The Requirement creation timestamp.
   *
   * @return RequirementInterface
   *   The called Requirement entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Requirement published status indicator.
   *
   * Unpublished Requirement are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Requirement is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Requirement.
   *
   * @param bool $published
   *   TRUE to set this Requirement to published, FALSE to set it to unpublished.
   *
   * @return RequirementInterface
   *   The called Requirement entity.
   */
  public function setPublished($published);

  /**
   * Returns the Requirements ignored indicator.
   *
   * @return bool
   *   TRUE if the Requirement is ignored.
   */
  public function isIgnored();

  /**
   * @param string $key
   * @param string $label
   * @return RequirementInterface
   *
   * @throws \Exception
   */
  public static function findOrCreate($key, $label);

  /**
   * @return array
   */
  public static function getCategoryKeys();

}
